pub enum PValueType {
TwoSided,
OneSidedRightTail,
OneSidedLeftTail,
}Expand description
Part of the statistic distribution to use for the p-value https://en.wikipedia.org/wiki/P-value#Probability_of_obtaining_a_real-valued_test_statistic_at_least_as_extreme_as_the_one_actually_obtained
Variants
TwoSided
Two-sided test - symmetric with respect to the mean of the statistic distribution 2 * min (Pr(T >= t | H0), Pr(T <= t | H0))
OneSidedRightTail
One-sided test (right tail) Pr(T >= t | H0)
OneSidedLeftTail
One-sided test (left tail) Pr(T <= t | H0)